==> wims_3.56.orig.tar.gz: public_html/modules/H6/analysis/oeftablevar.fr/src/cpp/antdonne.cpp <==
target=antdonne

#include "header.inc"

\title{Nombre d&#39;antcdents donn}
#include "values.inc"
#include "tablegen.inc"
#include "common.inc"

\integer{n=random(1,2,3,4)}
\text{zone=}
\text{point=}
\text{ante=\n = 1 ? antcdent:antcdents}
\statement{\intro

#include "table.inc"

Trouvez une valeur \(y_0) de \(f) ayant exactement \n \ante.
<p><center>
 \(y_0) = \embed{reply1,15}
</center>

}

\answer{\(y_0)}{\y0}{type=auto}

\integer{z=0}
\for{i=1 to \tabcnt}{
 \if{(\y0 > \YY[\i] and \y0 < \YY[\i+1]) or
     (\y0 < \YY[\i] and \y0 > \YY[\i+1])}{
  \integer{z=\z+1}
  \text{zone=\zone \i}
 }
 \if{\i>1 and \y0 = \YY[\i]}{
  \integer{z=\z+1}
  \text{point=\point \i}
  \text{minmax=\arrows[\i] issametext ne?Min:Max}
 }
}

\condition{\(\y0) a exactement \n \ante}{\z=\n}

\text{zone=wims(words2items \zone)}
\integer{zonecnt=items(\zone)}
\text{point=wims(words2items \point)}

\feedback{\z!=\n}{
 Nombre d&#39;antcdents de \(\y0) : \z. <p>
 \if{\z=0}{
  \(\y0) est
  \if{\y0<\ys[2]}{au-dessous de}{au-dessus de}
  l&#39;image de \(f). Elle n&#39;a donc aucun antcdent.
 }
 \if{\z=1}{
  \if{\point notsametext \empty}{
   \(\y0) est gale  \minmax(\(f)), atteint en \(x = \xs[\point]).
  }{
   \(\y0) a un unique antcdent dans l&#39;intervalle
   \rightbrack\xshow[\zone],\xshow[\zone+1]\leftbrack.
  }
 }
 \if{\z>1}{
  \if{\zonecnt>1}{
   \(\y0) a un antcdent dans chacun des intervalles suivants :
   <br><center>
   \for{t in \zone}{
    \rightbrack\xshow[\t],\xshow[\t+1]\leftbrack &nbsp;&nbsp;
   }
   </center> <p>
  }{
   \(\y0) a un antcdent dans l&#39;intervalle
   \rightbrack\xshow[\zone],\xshow[\zone+1]\leftbrack. <p>
  }
  \if{\point notsametext \empty}{
   Elle est aussi gale  \(f(\xs[\point])).
  }
 }
}

==> wims_3.60.orig.tar.gz: public_html/modules/H6/analysis/oeftablevar.fr/src/cpp/antdonne.cpp <==
target=antdonne

#include "header.inc"

\title{Nombre d&#39;antcdents donn}
#include "values.inc"
#include "tablegen.inc"
#include "common.inc"

\integer{n=random(1,2,3,4)}
\text{zone=}
\text{point=}
\text{ante=\n = 1 ? antcdent:antcdents}
\statement{\intro

#include "table.inc"

Trouvez une valeur \(y_0) de \(f) ayant exactement \n \ante.
<p><center>
 \(y_0) = \embed{reply1,15}
</center>

}

\answer{\(y_0)}{\y0}{type=auto}

\integer{z=0}
\for{i=1 to \tabcnt}{
 \if{(\y0 > \YY[\i] and \y0 < \YY[\i+1]) or
     (\y0 < \YY[\i] and \y0 > \YY[\i+1])}{
  \integer{z=\z+1}
  \text{zone=\zone \i}
 }
 \real{vtest=simplify(\y0 - \YY[\i])}
 \if{\i>1 and \vtest=0}{
  \integer{z=\z+1}
  \text{point=\point \i}
  \text{minmax=\arrows[\i] issametext ne?Min:Max}
 }
}

\condition{\(\y0) a exactement \n \ante}{\z=\n}

\text{zone=wims(words2items \zone)}
\integer{zonecnt=items(\zone)}
\text{point=wims(words2items \point)}

\feedback{1=1}{vtest=\vtest}

\feedback{\z!=\n}{
 Nombre d&#39;antcdents de \(\y0) : \z. <p>
 \if{\z=0}{
  \(\y0) est
  \if{\y0<\ys[2]}{au-dessous de}{au-dessus de}
  l&#39;image de \(f). Elle n&#39;a donc aucun antcdent.
 }
 \if{\z=1}{
  \if{\point notsametext \empty}{
   \(\y0) est gale  \minmax(\(f)), atteint en \(x = \xs[\point]).
  }{
   \(\y0) a un unique antcdent dans l&#39;intervalle
   \rightbrack\xshow[\zone],\xshow[\zone+1]\leftbrack.
  }
 }
 \if{\z>1}{
  \if{\zonecnt>1}{
   \(\y0) a un antcdent dans chacun des intervalles suivants :
   <br><center>
   \for{t in \zone}{
    \rightbrack\xshow[\t],\xshow[\t+1]\leftbrack &nbsp;&nbsp;
   }
   </center> <p>
  }{
   \(\y0) a un antcdent dans l&#39;intervalle
   \rightbrack\xshow[\zone],\xshow[\zone+1]\leftbrack. <p>
  }
  \if{\point notsametext \empty}{
   Elle est aussi gale  \(f(\xs[\point])).
  }
 }
}
